@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "password-store-menu" "1.2.0"
+(define-package "password-store-menu" "20250706.1858"
   "A better, more complete UI for password-store."
   '((emacs          "29.1")
     (password-store "2.3.2")
